From 044a115d6e158f2f2c1ce79cfa08a828015d292c Mon Sep 17 00:00:00 2001
From: Jonas Jenwald <jonas.jenwald@gmail.com>
Date: Thu, 18 May 2017 12:35:05 +0200
Subject: [PATCH 1/2] Change the `importl10n` script to use the Nightly channel

It seems that PR 8323 unfortunately didn't pick the right channel for pulling translations from, according to the information in:
 - https://groups.google.com/forum/#!topic/mozilla.dev.l10n/vzmbHLPo3rg
 - https://github.com/mozilla-l10n/localizer-documentation/blob/master/misc/aurora_faqs.md

My apologies for the unnecessary churn in this code!
---
 .github/CONTRIBUTING.md        |  2 +-
 external/importL10n/locales.js | 11 +++++------
 2 files changed, 6 insertions(+), 7 deletions(-)

diff --git a/.github/CONTRIBUTING.md b/.github/CONTRIBUTING.md
index f37332213..3daa7baa7 100644
--- a/.github/CONTRIBUTING.md
+++ b/.github/CONTRIBUTING.md
@@ -8,7 +8,7 @@ The issue tracking system is designed to record a single technical problem. A bu
 
 If you are developing a custom solution, first check the examples at https://github.com/mozilla/pdf.js#learning and search existing issues. If this does not help, please prepare a short well-documented example that demonstrates the problem and make it accessible online on your website, JS Bin, GitHub, etc. before opening a new issue or contacting us on the IRC channel -- keep in mind that just code snippets won't help us troubleshoot the problem.
 
-Note that the translations for PDF.js in the `l10n` folder are synchronized with the Beta branch of Mozilla Firefox. This means that we will only accept pull requests that add strings currently missing in the Beta branch (because it will take at least six weeks before the most recent translations are in the Beta branch), but keep in mind that the changes will be overwritten when we synchronize again.
+Note that the translations for PDF.js in the `l10n` folder are synchronized with the Nightly channel of Mozilla Firefox. This means that we will only accept pull requests that add strings currently missing in the Nightly channel, but keep in mind that the changes will be overwritten when we synchronize again.
 
 See also:
 - https://github.com/mozilla/pdf.js/wiki/Frequently-Asked-Questions
From 95660a2ab3b2d37203f2762fdb8e1f0b8014decb Mon Sep 17 00:00:00 2001
From: Jonas Jenwald <jonas.jenwald@gmail.com>
Date: Thu, 18 May 2017 12:41:01 +0200
Subject: [PATCH 2/2] Update l10n files

---
 l10n/ach/viewer.properties   |   3 +-
 l10n/af/viewer.properties    |   5 +-
 l10n/ak/viewer.properties    |   2 -
 l10n/an/viewer.properties    |   4 +-
 l10n/ar/viewer.properties    |   3 +-
 l10n/as/viewer.properties    |   2 -
 l10n/ast/viewer.properties   |   1 -
 l10n/az/viewer.properties    |   3 +-
 l10n/be/viewer.properties    |   5 +-
 l10n/bg/viewer.properties    |   3 +-
 l10n/bn-BD/viewer.properties |   2 -
 l10n/bn-IN/viewer.properties |   1 -
 l10n/br/viewer.properties    |   3 +-
 l10n/bs/viewer.properties    |   3 +-
 l10n/ca/viewer.properties    |   4 +-
 l10n/cs/viewer.properties    |   3 +-
 l10n/cy/viewer.properties    |   3 +-
 l10n/el/viewer.properties    |   3 +-
 l10n/en-GB/viewer.properties |   1 -
 l10n/en-ZA/viewer.properties |   3 +-
 l10n/eo/viewer.properties    |   3 +-
 l10n/es-AR/viewer.properties |   3 +-
 l10n/es-CL/viewer.properties |   3 +-
 l10n/es-ES/viewer.properties |   3 +-
 l10n/es-MX/viewer.properties |   3 +-
 l10n/et/viewer.properties    |   4 +-
 l10n/eu/viewer.properties    |   2 -
 l10n/fa/viewer.properties    |   3 +-
 l10n/ff/viewer.properties    |   2 -
 l10n/fi/viewer.properties    |   3 +-
 l10n/fr/viewer.properties    |   3 +-
 l10n/fy-NL/viewer.properties |   3 +-
 l10n/ga-IE/viewer.properties |   3 +-
 l10n/gd/viewer.properties    |   2 -
 l10n/gl/viewer.properties    |   1 -
 l10n/gu-IN/viewer.properties |   1 -
 l10n/he/viewer.properties    |   3 +-
 l10n/hi-IN/viewer.properties |   2 -
 l10n/hr/viewer.properties    |   2 -
 l10n/hu/viewer.properties    |   3 +-
 l10n/hy-AM/viewer.properties |   2 -
 l10n/id/viewer.properties    |   3 +-
 l10n/is/viewer.properties    |   3 +-
 l10n/it/viewer.properties    |   3 +-
 l10n/ka/viewer.properties    |   1 -
 l10n/kk/viewer.properties    |   5 +-
 l10n/km/viewer.properties    |   1 -
 l10n/kn/viewer.properties    |   2 -
 l10n/ko/viewer.properties    |   3 +-
 l10n/ku/viewer.properties    |   2 -
 l10n/lg/viewer.properties    |   1 -
 l10n/lij/viewer.properties   |   3 +-
 l10n/lt/viewer.properties    |   2 -
 l10n/lv/viewer.properties    |   3 +-
 l10n/mai/viewer.properties   |   2 -
 l10n/mk/viewer.properties    |   1 -
 l10n/ml/viewer.properties    |   2 -
 l10n/mn/viewer.properties    |   1 -
 l10n/mr/viewer.properties    |   2 -
 l10n/ms/viewer.properties    |   3 +-
 l10n/my/viewer.properties    |   3 +-
 l10n/nb-NO/viewer.properties |   1 -
 l10n/nn-NO/viewer.properties |   3 +-
 l10n/nso/viewer.properties   |   2 -
 l10n/oc/viewer.properties    |   2 -
 l10n/or/viewer.properties    |   2 -
 l10n/pa-IN/viewer.properties |   2 -
 l10n/pl/viewer.properties    |   3 +-
 l10n/pt-BR/viewer.properties |   3 +-
 l10n/pt-PT/viewer.properties |  15 +-
 l10n/rm/viewer.properties    |   1 -
 l10n/ro/viewer.properties    |   3 +-
 l10n/ru/viewer.properties    | 298 +++++++++++++++++++++--------------
 l10n/rw/viewer.properties    |   2 -
 l10n/sah/viewer.properties   |   2 -
 l10n/si/viewer.properties    |   1 -
 l10n/sk/viewer.properties    |   3 +-
 l10n/sl/viewer.properties    |   3 +-
 l10n/son/viewer.properties   |   4 +-
 l10n/sq/viewer.properties    |   3 +-
 l10n/sr/viewer.properties    |   3 +-
 l10n/sv-SE/viewer.properties |   2 +-
 l10n/sw/viewer.properties    |   2 -
 l10n/ta/viewer.properties    |   2 -
 l10n/te/viewer.properties    |   1 -
 l10n/th/viewer.properties    |   4 +-
 l10n/tl/viewer.properties    |   2 +
 l10n/tn/viewer.properties    |   1 -
 l10n/tr/viewer.properties    |   9 +-
 l10n/uk/viewer.properties    |   3 +-
 l10n/ur/viewer.properties    |   2 -
 l10n/vi/viewer.properties    |   5 +-
 l10n/wo/viewer.properties    |   1 -
 l10n/xh/viewer.properties    |   2 -
 l10n/zh-CN/viewer.properties |   3 +-
 l10n/zh-TW/viewer.properties |   3 +-
 l10n/zu/viewer.properties    |   2 -
 97 files changed, 306 insertions(+), 251 deletions(-)

diff --git a/l10n/ach/viewer.properties b/l10n/ach/viewer.properties
index b5031f5b2..177939b0d 100644
--- a/l10n/ach/viewer.properties
+++ b/l10n/ach/viewer.properties
@@ -119,7 +119,8 @@ thumb_page_title=Pot buk {{page}}
 thumb_page_canvas=Cal me pot buk {{page}}
 
 # Find panel button title and messages
-find_label=Nong:
+find_input.title=Nong
+find_input.placeholder=Nong i dokumen…
 find_previous.title=Nong timme pa lok mukato
 find_previous_label=Mukato
 find_next.title=Nong timme pa lok malubo
diff --git a/l10n/af/viewer.properties b/l10n/af/viewer.properties
index 70c36d531..c5aa38466 100644
--- a/l10n/af/viewer.properties
+++ b/l10n/af/viewer.properties
@@ -121,12 +121,13 @@ thumb_page_title=Bladsy {{page}}
 thumb_page_canvas=Duimnael van bladsy {{page}}
 
 # Find panel button title and messages
-find_label=Vind:
+find_input.title=Vind
+find_input.placeholder=Soek in dokument…
 find_previous.title=Vind die vorige voorkoms van die frase
 find_previous_label=Vorige
 find_next.title=Vind die volgende voorkoms van die frase
 find_next_label=Volgende
-find_highlight=Verlig alle
+find_highlight=Verlig almal
 find_match_case_label=Kassensitief
 find_reached_top=Bokant van dokument is bereik; gaan voort van onder af
 find_reached_bottom=Einde van dokument is bereik; gaan voort van bo af
diff --git a/l10n/ak/viewer.properties b/l10n/ak/viewer.properties
index ed7b70fc0..25dc62e37 100644
--- a/l10n/ak/viewer.properties
+++ b/l10n/ak/viewer.properties
@@ -65,7 +65,6 @@ document_outline_label=Dɔkomɛnt bɔbea
 thumbs.title=Kyerɛ mfoniwaa
 thumbs_label=Mfoniwaa
 findbar.title=Hu wɔ dɔkomɛnt no mu
-findbar_label=Hu
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -76,7 +75,6 @@ thumb_page_title=Krataafa {{page}}
 thumb_page_canvas=Krataafa ne mfoniwaa {{page}}
 
 # Find panel button title and messages
-find_label=Hunu:
 find_previous.title=San hu fres wɔ ekyiri baako
 find_previous_label=Ekyiri baako
 find_next.title=San hu fres no wɔ enim baako
diff --git a/l10n/an/viewer.properties b/l10n/an/viewer.properties
index 65b6a6005..e1ac1d5c8 100644
--- a/l10n/an/viewer.properties
+++ b/l10n/an/viewer.properties
@@ -101,6 +101,7 @@ print_progress_close=Cancelar
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
 toggle_sidebar.title=Amostrar u amagar a barra lateral
+toggle_sidebar_notification.title=Cambiar barra lateral (lo documento contiene esquema/adchuntos)
 toggle_sidebar_label=Amostrar a barra lateral
 document_outline.title=Amostrar esquema d'o documento (fer doble clic pa expandir/compactar totz los items)
 document_outline_label=Esquema d'o documento
@@ -120,7 +121,8 @@ thumb_page_title=Pachina {{page}}
 thumb_page_canvas=Miniatura d'a pachina {{page}}
 
 # Find panel button title and messages
-find_label=Trobar:
+find_input.title=Trobar
+find_input.placeholder=Trobar en o documento…
 find_previous.title=Trobar l'anterior coincidencia d'a frase
 find_previous_label=Anterior
 find_next.title=Trobar a siguient coincidencia d'a frase
diff --git a/l10n/ar/viewer.properties b/l10n/ar/viewer.properties
index 01d2141f9..f408b7e9a 100644
--- a/l10n/ar/viewer.properties
+++ b/l10n/ar/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=صفحة {{page}}
 thumb_page_canvas=مصغّرة صفحة {{page}}
 
 # Find panel button title and messages
-find_label=ابحث:
+find_input.title=ابحث
+find_input.placeholder=ابحث في المستند…
 find_previous.title=ابحث عن التّواجد السّابق للعبارة
 find_previous_label=السابق
 find_next.title=ابحث عن التّواجد التّالي للعبارة
diff --git a/l10n/as/viewer.properties b/l10n/as/viewer.properties
index f0e4d9e14..2becaac01 100644
--- a/l10n/as/viewer.properties
+++ b/l10n/as/viewer.properties
@@ -102,7 +102,6 @@ attachments_label=এটাচমেন্টসমূহ
 thumbs.title=থাম্বনেইলসমূহ দেখুৱাওক
 thumbs_label=থাম্বনেইলসমূহ
 findbar.title=দস্তাবেজত সন্ধান কৰক
-findbar_label=সন্ধান কৰক
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -113,7 +112,6 @@ thumb_page_title=পৃষ্ঠা {{page}}
 thumb_page_canvas=পৃষ্ঠাৰ থাম্বনেইল {{page}}
 
 # Find panel button title and messages
-find_label=সন্ধান কৰক:
 find_previous.title=বাক্যাংশৰ পূৰ্বৱৰ্তী উপস্থিতি সন্ধান কৰক
 find_previous_label=পূৰ্বৱৰ্তী
 find_next.title=বাক্যাংশৰ পৰৱৰ্তী উপস্থিতি সন্ধান কৰক
diff --git a/l10n/ast/viewer.properties b/l10n/ast/viewer.properties
index 8c824968a..c22bf4943 100644
--- a/l10n/ast/viewer.properties
+++ b/l10n/ast/viewer.properties
@@ -120,7 +120,6 @@ thumb_page_title=Páxina {{page}}
 thumb_page_canvas=Miniatura de la páxina {{page}}
 
 # Find panel button title and messages
-find_label=Guetar:
 find_previous.title=Alcontrar l'anterior apaición de la fras
 find_previous_label=Anterior
 find_next.title=Alcontrar la siguiente apaición d'esta fras
diff --git a/l10n/az/viewer.properties b/l10n/az/viewer.properties
index 4e72674e9..b57122133 100644
--- a/l10n/az/viewer.properties
+++ b/l10n/az/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Səhifə{{page}}
 thumb_page_canvas={{page}} səhifəsinin kiçik vəziyyəti
 
 # Find panel button title and messages
-find_label=Tap:
+find_input.title=Tap
+find_input.placeholder=Sənəddə tap…
 find_previous.title=Bir öncəki uyğun gələn sözü tapır
 find_previous_label=Geri
 find_next.title=Bir sonrakı uyğun gələn sözü tapır
diff --git a/l10n/be/viewer.properties b/l10n/be/viewer.properties
index 503c2f89f..327f021c0 100644
--- a/l10n/be/viewer.properties
+++ b/l10n/be/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Старонка {{page}}
 thumb_page_canvas=Мініяцюра старонкі {{page}}
 
 # Find panel button title and messages
-find_label=Пошук:
+find_input.title=Шукаць
+find_input.placeholder=Шукаць у дакуменце…
 find_previous.title=Знайсці папярэдні выпадак выразу
 find_previous_label=Папярэдні
 find_next.title=Знайсці наступны выпадак выразу
@@ -138,7 +139,7 @@ error_less_info=Сцісла
 error_close=Закрыць
 # LOCALIZATION NOTE (error_version_info): "{{version}}" and "{{build}}" will be
 # replaced by the PDF.JS version and build ID.
-error_version_info=PDF.js в{{version}} (пабудова: {{build}})
+error_version_info=PDF.js в{{version}} (зборка: {{build}})
 # LOCALIZATION NOTE (error_message): "{{message}}" will be replaced by an
 # english string describing the error.
 error_message=Паведамленне: {{message}}
diff --git a/l10n/bg/viewer.properties b/l10n/bg/viewer.properties
index 1a8282322..d698dbf64 100644
--- a/l10n/bg/viewer.properties
+++ b/l10n/bg/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Страница {{page}}
 thumb_page_canvas=Миниатюра на страница {{page}}
 
 # Find panel button title and messages
-find_label=Търсене:
+find_input.title=Търсене
+find_input.placeholder=Търсене в документа…
 find_previous.title=Намиране на предишно съвпадение на фразата
 find_previous_label=Предишна
 find_next.title=Намиране на следващо съвпадение на фразата
diff --git a/l10n/bn-BD/viewer.properties b/l10n/bn-BD/viewer.properties
index 9812cd270..d2655fb4c 100644
--- a/l10n/bn-BD/viewer.properties
+++ b/l10n/bn-BD/viewer.properties
@@ -110,7 +110,6 @@ attachments_label=সংযুক্তি
 thumbs.title=থাম্বনেইল সমূহ প্রদর্শন করুন
 thumbs_label=থাম্বনেইল সমূহ
 findbar.title=নথির মধ্যে খুঁজুন
-findbar_label=অনুসন্ধান
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -121,7 +120,6 @@ thumb_page_title=পৃষ্ঠা {{page}}
 thumb_page_canvas={{page}} পৃষ্ঠার থাম্বনেইল
 
 # Find panel button title and messages
-find_label=অনুসন্ধান:
 find_previous.title=বাক্যাংশের পূর্ববর্তী উপস্থিতি অনুসন্ধান
 find_previous_label=পূর্ববর্তী
 find_next.title=বাক্যাংশের পরবর্তী উপস্থিতি অনুসন্ধান
diff --git a/l10n/bn-IN/viewer.properties b/l10n/bn-IN/viewer.properties
index 3fe4fc3bf..63efe71b5 100644
--- a/l10n/bn-IN/viewer.properties
+++ b/l10n/bn-IN/viewer.properties
@@ -120,7 +120,6 @@ thumb_page_title=পৃষ্ঠা {{page}}
 thumb_page_canvas=পৃষ্ঠা {{page}}-র থাম্ব-নেইল
 
 # Find panel button title and messages
-find_label=অনুসন্ধান:
 find_previous.title=চিহ্নিত পংক্তির পূর্ববর্তী উপস্থিতি অনুসন্ধান করুন
 find_previous_label=পূর্ববর্তী
 find_next.title=চিহ্নিত পংক্তির পরবর্তী উপস্থিতি অনুসন্ধান করুন
diff --git a/l10n/br/viewer.properties b/l10n/br/viewer.properties
index b207b4c63..dc3ca1f59 100644
--- a/l10n/br/viewer.properties
+++ b/l10n/br/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Pajenn {{page}}
 thumb_page_canvas=Melvenn ar bajenn {{page}}
 
 # Find panel button title and messages
-find_label=Kavout :
+find_input.title=Klask
+find_input.placeholder=Klask e-barzh an teuliad
 find_previous.title=Kavout an tamm frazenn kent o klotañ ganti
 find_previous_label=Kent
 find_next.title=Kavout an tamm frazenn war-lerc'h o klotañ ganti
diff --git a/l10n/bs/viewer.properties b/l10n/bs/viewer.properties
index b9d0c693c..2f70ecdd6 100644
--- a/l10n/bs/viewer.properties
+++ b/l10n/bs/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Strana {{page}}
 thumb_page_canvas=Thumbnail strane {{page}}
 
 # Find panel button title and messages
-find_label=Pronađi:
+find_input.title=Pronađi
+find_input.placeholder=Pronađi u dokumentu…
 find_previous.title=Pronađi prethodno pojavljivanje fraze
 find_previous_label=Prethodno
 find_next.title=Pronađi sljedeće pojavljivanje fraze
diff --git a/l10n/ca/viewer.properties b/l10n/ca/viewer.properties
index f360b3466..cc633e289 100644
--- a/l10n/ca/viewer.properties
+++ b/l10n/ca/viewer.properties
@@ -101,6 +101,7 @@ print_progress_close=Cancel·la
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
 toggle_sidebar.title=Mostra/amaga la barra lateral
+toggle_sidebar_notification.title=Mostra/amaga la barra lateral (el document conté un esquema o adjuncions)
 toggle_sidebar_label=Mostra/amaga la barra lateral
 document_outline.title=Mostra l'esquema del document (doble clic per ampliar/reduir tots els elements)
 document_outline_label=Contorn del document
@@ -120,7 +121,8 @@ thumb_page_title=Pàgina {{page}}
 thumb_page_canvas=Miniatura de la pàgina {{page}}
 
 # Find panel button title and messages
-find_label=Cerca:
+find_input.title=Cerca
+find_input.placeholder=Cerca al document…
 find_previous.title=Cerca l'anterior coincidència de l'expressió
 find_previous_label=Anterior
 find_next.title=Cerca la següent coincidència de l'expressió
diff --git a/l10n/cs/viewer.properties b/l10n/cs/viewer.properties
index f0a2399ec..e9ef66dc6 100644
--- a/l10n/cs/viewer.properties
+++ b/l10n/cs/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Strana {{page}}
 thumb_page_canvas=Náhled strany {{page}}
 
 # Find panel button title and messages
-find_label=Najít:
+find_input.title=Najít
+find_input.placeholder=Najít v dokumentu…
 find_previous.title=Najde předchozí výskyt hledaného textu
 find_previous_label=Předchozí
 find_next.title=Najde další výskyt hledaného textu
diff --git a/l10n/cy/viewer.properties b/l10n/cy/viewer.properties
index ccc9b5ba2..6096c6a51 100644
--- a/l10n/cy/viewer.properties
+++ b/l10n/cy/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Tudalen {{page}}
 thumb_page_canvas=Llun Bach Tudalen {{page}}
 
 # Find panel button title and messages
-find_label=Canfod:
+find_input.title=Canfod
+find_input.placeholder=Canfod yn y ddogfen…
 find_previous.title=Canfod enghraifft flaenorol o'r ymadrodd
 find_previous_label=Blaenorol
 find_next.title=Canfod enghraifft nesaf yr ymadrodd
diff --git a/l10n/el/viewer.properties b/l10n/el/viewer.properties
index f034a574f..086db2ef5 100644
--- a/l10n/el/viewer.properties
+++ b/l10n/el/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Σελίδα {{page}}
 thumb_page_canvas=Μικρογραφία της σελίδας {{page}}
 
 # Find panel button title and messages
-find_label=Εύρεση:
+find_input.title=Εύρεση
+find_input.placeholder=Εύρεση στο έγγραφο…
 find_previous.title=Εύρεση της προηγούμενης εμφάνισης της φράσης
 find_previous_label=Προηγούμενο
 find_next.title=Εύρεση της επόμενης εμφάνισης της φράσης
diff --git a/l10n/en-GB/viewer.properties b/l10n/en-GB/viewer.properties
index 696ab411f..8fc92aaac 100644
--- a/l10n/en-GB/viewer.properties
+++ b/l10n/en-GB/viewer.properties
@@ -120,7 +120,6 @@ thumb_page_title=Page {{page}}
 thumb_page_canvas=Thumbnail of Page {{page}}
 
 # Find panel button title and messages
-find_label=Find:
 find_previous.title=Find the previous occurrence of the phrase
 find_previous_label=Previous
 find_next.title=Find the next occurrence of the phrase
diff --git a/l10n/en-ZA/viewer.properties b/l10n/en-ZA/viewer.properties
index 4f9a88678..5b287f744 100644
--- a/l10n/en-ZA/viewer.properties
+++ b/l10n/en-ZA/viewer.properties
@@ -21,6 +21,7 @@ next_label=Next
 # LOCALIZATION NOTE (page.title): The tooltip for the pageNumber input.
 # LOCALIZATION NOTE (of_pages): "{{pagesCount}}" will be replaced by a number
 # representing the total number of pages in the document.
+of_pages=of {{pagesCount}}
 # LOCALIZATION NOTE (page_of_pages): "{{pageNumber}}" and "{{pagesCount}}"
 # will be replaced by a number representing the currently visible page,
 # respectively a number representing the total number of pages in the document.
@@ -103,7 +104,6 @@ attachments_label=Attachments
 thumbs.title=Show Thumbnails
 thumbs_label=Thumbnails
 findbar.title=Find in Document
-findbar_label=Find
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -114,7 +114,6 @@ thumb_page_title=Page {{page}}
 thumb_page_canvas=Thumbnail of Page {{page}}
 
 # Find panel button title and messages
-find_label=Find:
 find_previous.title=Find the previous occurrence of the phrase
 find_previous_label=Previous
 find_next.title=Find the next occurrence of the phrase
diff --git a/l10n/eo/viewer.properties b/l10n/eo/viewer.properties
index 5e9b07363..26d2f5ee7 100644
--- a/l10n/eo/viewer.properties
+++ b/l10n/eo/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Paĝo {{page}}
 thumb_page_canvas=Miniaturo de paĝo {{page}}
 
 # Find panel button title and messages
-find_label=Serĉi:
+find_input.title=Serĉi
+find_input.placeholder=Serĉi en dokumento…
 find_previous.title=Serĉi la antaŭan aperon de la frazo
 find_previous_label=Malantaŭen
 find_next.title=Serĉi la venontan aperon de la frazo
diff --git a/l10n/es-AR/viewer.properties b/l10n/es-AR/viewer.properties
index cc5744c06..d37127c78 100644
--- a/l10n/es-AR/viewer.properties
+++ b/l10n/es-AR/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Página {{page}}
 thumb_page_canvas=Miniatura de página {{page}}
 
 # Find panel button title and messages
-find_label=Buscar:
+find_input.title=Buscar
+find_input.placeholder=Buscar en documento…
 find_previous.title=Buscar la aparición anterior de la frase
 find_previous_label=Anterior
 find_next.title=Buscar la siguiente aparición de la frase
diff --git a/l10n/es-CL/viewer.properties b/l10n/es-CL/viewer.properties
index 568735cf6..cd76ac253 100644
--- a/l10n/es-CL/viewer.properties
+++ b/l10n/es-CL/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Página {{page}}
 thumb_page_canvas=Miniatura de la página {{page}}
 
 # Find panel button title and messages
-find_label=Buscar:
+find_input.title=Encontrar
+find_input.placeholder=Encontrar en el documento…
 find_previous.title=Buscar la aparición anterior de la frase
 find_previous_label=Previo
 find_next.title=Buscar la siguiente aparición de la frase
diff --git a/l10n/es-ES/viewer.properties b/l10n/es-ES/viewer.properties
index acedf77b4..ef508181a 100644
--- a/l10n/es-ES/viewer.properties
+++ b/l10n/es-ES/viewer.properties
@@ -76,7 +76,8 @@ findbar.title = Buscar en el documento
 findbar_label = Buscar
 thumb_page_title = Página {{page}}
 thumb_page_canvas = Miniatura de la página {{page}}
-find_label = Buscar:
+find_input.title = Buscar
+find_input.placeholder = Buscar en el documento…
 find_previous.title = Encontrar la anterior aparición de la frase
 find_previous_label = Anterior
 find_next.title = Encontrar la siguiente aparición de esta frase
diff --git a/l10n/es-MX/viewer.properties b/l10n/es-MX/viewer.properties
index 3b1bfeaa3..aef90c65f 100644
--- a/l10n/es-MX/viewer.properties
+++ b/l10n/es-MX/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Página {{page}}
 thumb_page_canvas=Miniatura de la página {{page}}
 
 # Find panel button title and messages
-find_label=Encontrar:
+find_input.title=Buscar
+find_input.placeholder=Buscar en el documento…
 find_previous.title=Ir a la anterior frase encontrada
 find_previous_label=Anterior
 find_next.title=Ir a la siguiente frase encontrada
diff --git a/l10n/et/viewer.properties b/l10n/et/viewer.properties
index 1b52857f4..b9089f88c 100644
--- a/l10n/et/viewer.properties
+++ b/l10n/et/viewer.properties
@@ -101,6 +101,7 @@ print_progress_close=Loobu
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
 toggle_sidebar.title=Näita külgriba
+toggle_sidebar_notification.title=Näita külgriba (dokument sisaldab sisukorda/manuseid)
 toggle_sidebar_label=Näita külgriba
 document_outline.title=Näita sisukorda (kõigi punktide laiendamiseks/ahendamiseks topeltklõpsa)
 document_outline_label=Näita sisukorda
@@ -120,7 +121,8 @@ thumb_page_title={{page}}. lehekülg
 thumb_page_canvas={{page}}. lehekülje pisipilt
 
 # Find panel button title and messages
-find_label=Otsi:
+find_input.title=Otsi
+find_input.placeholder=Otsi dokumendist…
 find_previous.title=Otsi fraasi eelmine esinemiskoht
 find_previous_label=Eelmine
 find_next.title=Otsi fraasi järgmine esinemiskoht
diff --git a/l10n/eu/viewer.properties b/l10n/eu/viewer.properties
index 15dcc9f6a..32b736669 100644
--- a/l10n/eu/viewer.properties
+++ b/l10n/eu/viewer.properties
@@ -110,7 +110,6 @@ attachments_label=Eranskinak
 thumbs.title=Erakutsi koadro txikiak
 thumbs_label=Koadro txikiak
 findbar.title=Bilatu dokumentuan
-findbar_label=Bilatu
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -121,7 +120,6 @@ thumb_page_title={{page}}. orria
 thumb_page_canvas={{page}}. orriaren koadro txikia
 
 # Find panel button title and messages
-find_label=Bilatu:
 find_previous.title=Bilatu esaldiaren aurreko parekatzea
 find_previous_label=Aurrekoa
 find_next.title=Bilatu esaldiaren hurrengo parekatzea
diff --git a/l10n/fa/viewer.properties b/l10n/fa/viewer.properties
index 7f2a8ace7..aee40841a 100644
--- a/l10n/fa/viewer.properties
+++ b/l10n/fa/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=صفحه {{page}}
 thumb_page_canvas=تصویر بند‌ انگشتی صفحه {{page}}
 
 # Find panel button title and messages
-find_label=جستجو:
+find_input.title=پیدا کردن
+find_input.placeholder=پیدا کردن در سند…
 find_previous.title=پیدا کردن رخداد قبلی عبارت
 find_previous_label=قبلی
 find_next.title=پیدا کردن رخداد بعدی عبارت
diff --git a/l10n/ff/viewer.properties b/l10n/ff/viewer.properties
index c73fc9667..3a14e57d1 100644
--- a/l10n/ff/viewer.properties
+++ b/l10n/ff/viewer.properties
@@ -109,7 +109,6 @@ attachments_label=Ɗisanɗe
 thumbs.title=Hollu Dooɓe
 thumbs_label=Dooɓe
 findbar.title=Yiylo e fiilannde
-findbar_label=Yiytu
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -120,7 +119,6 @@ thumb_page_title=Hello {{page}}
 thumb_page_canvas=Dooɓre Hello {{page}}
 
 # Find panel button title and messages
-find_label=Yiytu:
 find_previous.title=Yiylo cilol ɓennugol konngol ngol
 find_previous_label=Ɓennuɗo
 find_next.title=Yiylo cilol garowol konngol ngol
diff --git a/l10n/fi/viewer.properties b/l10n/fi/viewer.properties
index 6296ed7f8..9bc6dcd12 100644
--- a/l10n/fi/viewer.properties
+++ b/l10n/fi/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Sivu {{page}}
 thumb_page_canvas=Pienoiskuva sivusta {{page}}
 
 # Find panel button title and messages
-find_label=Etsi:
+find_input.title=Etsi
+find_input.placeholder=Etsi dokumentista…
 find_previous.title=Etsi hakusanan edellinen osuma
 find_previous_label=Edellinen
 find_next.title=Etsi hakusanan seuraava osuma
diff --git a/l10n/fr/viewer.properties b/l10n/fr/viewer.properties
index e2a04c734..26d9eae4e 100644
--- a/l10n/fr/viewer.properties
+++ b/l10n/fr/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Page {{page}}
 thumb_page_canvas=Vignette de la page {{page}}
 
 # Find panel button title and messages
-find_label=Rechercher :
+find_input.title=Rechercher
+find_input.placeholder=Rechercher dans le document…
 find_previous.title=Trouver l’occurrence précédente de la phrase
 find_previous_label=Précédent
 find_next.title=Trouver la prochaine occurrence de la phrase
diff --git a/l10n/fy-NL/viewer.properties b/l10n/fy-NL/viewer.properties
index bfedc77fe..58b5f6c8b 100644
--- a/l10n/fy-NL/viewer.properties
+++ b/l10n/fy-NL/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Side {{page}}
 thumb_page_canvas=Foarbyld fan side {{page}}
 
 # Find panel button title and messages
-find_label=Sykje:
+find_input.title=Sykje
+find_input.placeholder=Sykje yn dokumint…
 find_previous.title=It foarige foarkommen fan de tekst sykje
 find_previous_label=Foarige
 find_next.title=It folgjende foarkommen fan de tekst sykje
diff --git a/l10n/ga-IE/viewer.properties b/l10n/ga-IE/viewer.properties
index c592a89d1..04df1fcab 100644
--- a/l10n/ga-IE/viewer.properties
+++ b/l10n/ga-IE/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Leathanach {{page}}
 thumb_page_canvas=Mionsamhail Leathanaigh {{page}}
 
 # Find panel button title and messages
-find_label=Aimsigh:
+find_input.title=Aimsigh
+find_input.placeholder=Aimsigh sa cháipéis…
 find_previous.title=Aimsigh an sampla roimhe seo den nath seo
 find_previous_label=Roimhe seo
 find_next.title=Aimsigh an chéad sampla eile den nath sin
diff --git a/l10n/gd/viewer.properties b/l10n/gd/viewer.properties
index c6503b8c0..b1981e7b2 100644
--- a/l10n/gd/viewer.properties
+++ b/l10n/gd/viewer.properties
@@ -110,7 +110,6 @@ attachments_label=Ceanglachain
 thumbs.title=Seall na dealbhagan
 thumbs_label=Dealbhagan
 findbar.title=Lorg san sgrìobhainn
-findbar_label=Lorg
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -121,7 +120,6 @@ thumb_page_title=Duilleag a {{page}}
 thumb_page_canvas=Dealbhag duilleag a {{page}}
 
 # Find panel button title and messages
-find_label=Lorg:
 find_previous.title=Lorg làthair roimhe na h-abairt seo
 find_previous_label=Air ais
 find_next.title=Lorg ath-làthair na h-abairt seo
diff --git a/l10n/gl/viewer.properties b/l10n/gl/viewer.properties
index ac088ae65..b7fa998ae 100644
--- a/l10n/gl/viewer.properties
+++ b/l10n/gl/viewer.properties
@@ -112,7 +112,6 @@ thumb_page_title=Páxina {{page}}
 thumb_page_canvas=Miniatura da páxina {{page}}
 
 # Find panel button title and messages
-find_label=Atopar:
 find_previous.title=Atopar a anterior aparición da frase
 find_previous_label=Anterior
 find_next.title=Atopar a seguinte aparición da frase
diff --git a/l10n/gu-IN/viewer.properties b/l10n/gu-IN/viewer.properties
index 9e69f5afd..818d94448 100644
--- a/l10n/gu-IN/viewer.properties
+++ b/l10n/gu-IN/viewer.properties
@@ -109,7 +109,6 @@ thumb_page_title=પાનું {{page}}
 thumb_page_canvas=પાનાં {{page}} નું થંબનેલ્સ
 
 # Find panel button title and messages
-find_label=શોધો:
 find_previous.title=શબ્દસમૂહની પાછલી ઘટનાને શોધો
 find_previous_label=પહેલાંનુ
 find_next.title=શબ્દસમૂહની આગળની ઘટનાને શોધો
diff --git a/l10n/he/viewer.properties b/l10n/he/viewer.properties
index ed8c1ceb0..a09b62d1d 100644
--- a/l10n/he/viewer.properties
+++ b/l10n/he/viewer.properties
@@ -120,7 +120,8 @@ thumb_page_title=עמוד {{page}}
 thumb_page_canvas=תצוגה מקדימה של עמוד {{page}}
 
 # Find panel button title and messages
-find_label=חיפוש:
+find_input.title=חיפוש
+find_input.placeholder=חיפוש במסמך…
 find_previous.title=חיפוש מופע קודם של הביטוי
 find_previous_label=קודם
 find_next.title=חיפוש המופע הבא של הביטוי
diff --git a/l10n/hi-IN/viewer.properties b/l10n/hi-IN/viewer.properties
index e5f6f9780..7fdc33d6c 100644
--- a/l10n/hi-IN/viewer.properties
+++ b/l10n/hi-IN/viewer.properties
@@ -109,7 +109,6 @@ attachments_label=संलग्नक
 thumbs.title=लघुछवियाँ दिखाएँ
 thumbs_label=लघु छवि
 findbar.title=\u0020दस्तावेज़ में ढूँढ़ें
-findbar_label=ढूँढ़ें
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -120,7 +119,6 @@ thumb_page_title=पृष्ठ {{page}}
 thumb_page_canvas=पृष्ठ {{page}} की लघु-छवि
 
 # Find panel button title and messages
-find_label=ढूंढें:
 find_previous.title=वाक्यांश की पिछली उपस्थिति ढूँढ़ें
 find_previous_label=पिछला
 find_next.title=वाक्यांश की अगली उपस्थिति ढूँढ़ें
diff --git a/l10n/hr/viewer.properties b/l10n/hr/viewer.properties
index 6503d99b2..fc36cdd2a 100644
--- a/l10n/hr/viewer.properties
+++ b/l10n/hr/viewer.properties
@@ -109,7 +109,6 @@ attachments_label=Privitci
 thumbs.title=Prikaži sličice
 thumbs_label=Sličice
 findbar.title=Traži u dokumentu
-findbar_label=Traži
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -120,7 +119,6 @@ thumb_page_title=Stranica {{page}}
 thumb_page_canvas=Sličica stranice {{page}}
 
 # Find panel button title and messages
-find_label=Traži:
 find_previous.title=Pronađi prethodno javljanje ovog izraza
 find_previous_label=Prethodno
 find_next.title=Pronađi iduće javljanje ovog izraza
diff --git a/l10n/hu/viewer.properties b/l10n/hu/viewer.properties
index 94af449bb..a7bd824d6 100644
--- a/l10n/hu/viewer.properties
+++ b/l10n/hu/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title={{page}}. oldal
 thumb_page_canvas={{page}}. oldal bélyegképe
 
 # Find panel button title and messages
-find_label=Keresés:
+find_input.title=Keresés
+find_input.placeholder=Keresés a dokumentumban…
 find_previous.title=A kifejezés előző előfordulásának keresése
 find_previous_label=Előző
 find_next.title=A kifejezés következő előfordulásának keresése
diff --git a/l10n/hy-AM/viewer.properties b/l10n/hy-AM/viewer.properties
index 3d8b5004e..de9f973ae 100644
--- a/l10n/hy-AM/viewer.properties
+++ b/l10n/hy-AM/viewer.properties
@@ -110,7 +110,6 @@ attachments_label=Կցորդներ
 thumbs.title=Ցուցադրել Մանրապատկերը
 thumbs_label=Մանրապատկերը
 findbar.title=Գտնել փաստաթղթում
-findbar_label=Որոնում
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -121,7 +120,6 @@ thumb_page_title=Էջը {{page}}
 thumb_page_canvas=Էջի մանրապատկերը {{page}}
 
 # Find panel button title and messages
-find_label=Գտնել`
 find_previous.title=Գտնել անրահայտության նախորդ հանդիպումը
 find_previous_label=Նախորդը
 find_next.title=Գտիր արտահայտության հաջորդ հանդիպումը
diff --git a/l10n/id/viewer.properties b/l10n/id/viewer.properties
index 2fd903303..9c6d66535 100644
--- a/l10n/id/viewer.properties
+++ b/l10n/id/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Laman {{page}}
 thumb_page_canvas=Miniatur Laman {{page}}
 
 # Find panel button title and messages
-find_label=Temukan:
+find_input.title=Temukan
+find_input.placeholder=Temukan di dokumen…
 find_previous.title=Temukan kata sebelumnya
 find_previous_label=Sebelumnya
 find_next.title=Temukan lebih lanjut
diff --git a/l10n/is/viewer.properties b/l10n/is/viewer.properties
index 325bf44c6..3ef9c985e 100644
--- a/l10n/is/viewer.properties
+++ b/l10n/is/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Síða {{page}}
 thumb_page_canvas=Smámynd af síðu {{page}}
 
 # Find panel button title and messages
-find_label=Leita:
+find_input.title=Leita
+find_input.placeholder=Leita í skjali…
 find_previous.title=Leita að fyrra tilfelli þessara orða
 find_previous_label=Fyrri
 find_next.title=Leita að næsta tilfelli þessara orða
diff --git a/l10n/it/viewer.properties b/l10n/it/viewer.properties
index 11b972eeb..c2bb9ab1d 100644
--- a/l10n/it/viewer.properties
+++ b/l10n/it/viewer.properties
@@ -76,7 +76,8 @@ findbar.title = Trova nel documento
 findbar_label = Trova
 thumb_page_title = Pagina {{page}}
 thumb_page_canvas = Miniatura della pagina {{page}}
-find_label = Trova:
+find_input.title = Trova
+find_input.placeholder = Trova nel documento…
 find_previous.title = Trova l’occorrenza precedente del testo da cercare
 find_previous_label = Precedente
 find_next.title = Trova l’occorrenza successiva del testo da cercare
diff --git a/l10n/ka/viewer.properties b/l10n/ka/viewer.properties
index ee3391ef4..942b4495a 100644
--- a/l10n/ka/viewer.properties
+++ b/l10n/ka/viewer.properties
@@ -112,7 +112,6 @@ thumb_page_title=გვერდი {{page}}
 thumb_page_canvas=გვერდის ესკიზი {{page}}
 
 # Find panel button title and messages
-find_label=პოვნა:
 find_previous.title=ფრაზის წინა კონტექსტის პოვნა
 find_previous_label=წინა
 find_next.title=ფრაზის შემდეგი კონტექსტის პოვნა
diff --git a/l10n/kk/viewer.properties b/l10n/kk/viewer.properties
index 8585de573..59fd94d96 100644
--- a/l10n/kk/viewer.properties
+++ b/l10n/kk/viewer.properties
@@ -76,7 +76,7 @@ document_properties_kb={{size_kb}} КБ ({{size_b}} байт)
 # LOCALIZATION NOTE (document_properties_mb): "{{size_mb}}" and "{{size_b}}"
 # will be replaced by the PDF file size in megabytes, respectively in bytes.
 document_properties_mb={{size_mb}} МБ ({{size_b}} байт)
-document_properties_title=Тақырыбы...
+document_properties_title=Тақырыбы:
 document_properties_author=Авторы:
 document_properties_subject=Тақырыбы:
 document_properties_keywords=Кілт сөздер:
@@ -121,7 +121,8 @@ thumb_page_title={{page}} парағы
 thumb_page_canvas={{page}} парағы үшін кіші көрінісі
 
 # Find panel button title and messages
-find_label=Табу:
+find_input.title=Табу
+find_input.placeholder=Құжаттан табу…
 find_previous.title=Осы сөздердің мәтіннен алдыңғы кездесуін табу
 find_previous_label=Алдыңғысы
 find_next.title=Осы сөздердің мәтіннен келесі кездесуін табу
diff --git a/l10n/km/viewer.properties b/l10n/km/viewer.properties
index 1d4d4b44f..c8a5ce046 100644
--- a/l10n/km/viewer.properties
+++ b/l10n/km/viewer.properties
@@ -121,7 +121,6 @@ thumb_page_title=ទំព័រ {{page}}
 thumb_page_canvas=រូបភាព​តូច​របស់​ទំព័រ {{page}}
 
 # Find panel button title and messages
-find_label=រក ៖
 find_previous.title=រក​ពាក្យ ឬ​ឃ្លា​ដែល​បាន​ជួប​មុន
 find_previous_label=មុន
 find_next.title=រក​ពាក្យ ឬ​ឃ្លា​ដែល​បាន​ជួប​បន្ទាប់
diff --git a/l10n/kn/viewer.properties b/l10n/kn/viewer.properties
index 620c805bb..2237609aa 100644
--- a/l10n/kn/viewer.properties
+++ b/l10n/kn/viewer.properties
@@ -103,7 +103,6 @@ attachments_label=ಲಗತ್ತುಗಳು
 thumbs.title=ಚಿಕ್ಕಚಿತ್ರದಂತೆ ತೋರಿಸು
 thumbs_label=ಚಿಕ್ಕಚಿತ್ರಗಳು
 findbar.title=ದಸ್ತಾವೇಜಿನಲ್ಲಿ ಹುಡುಕು
-findbar_label=ಹುಡುಕು
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -114,7 +113,6 @@ thumb_page_title=ಪುಟ {{page}}
 thumb_page_canvas=ಪುಟವನ್ನು ಚಿಕ್ಕಚಿತ್ರದಂತೆ ತೋರಿಸು {{page}}
 
 # Find panel button title and messages
-find_label=ಹುಡುಕು:
 find_previous.title=ವಾಕ್ಯದ ಹಿಂದಿನ ಇರುವಿಕೆಯನ್ನು ಹುಡುಕು
 find_previous_label=ಹಿಂದಿನ
 find_next.title=ವಾಕ್ಯದ ಮುಂದಿನ ಇರುವಿಕೆಯನ್ನು ಹುಡುಕು
diff --git a/l10n/ko/viewer.properties b/l10n/ko/viewer.properties
index 38207a522..add1a9eb5 100644
--- a/l10n/ko/viewer.properties
+++ b/l10n/ko/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title={{page}}쪽
 thumb_page_canvas={{page}}쪽 미리보기
 
 # Find panel button title and messages
-find_label=검색:
+find_input.title=찾기
+find_input.placeholder=문서에서 찾기…
 find_previous.title=지정 문자열에 일치하는 1개 부분을 검색
 find_previous_label=이전
 find_next.title=지정 문자열에 일치하는 다음 부분을 검색
diff --git a/l10n/ku/viewer.properties b/l10n/ku/viewer.properties
index 6af3ec064..c3462f67d 100644
--- a/l10n/ku/viewer.properties
+++ b/l10n/ku/viewer.properties
@@ -79,7 +79,6 @@ document_outline_label=Şemaya belgeyê
 thumbs.title=Wênekokan nîşan bide
 thumbs_label=Wênekok
 findbar.title=Di belgeyê de bibîne
-findbar_label=Bibîne
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -90,7 +89,6 @@ thumb_page_title=Rûpel {{page}}
 thumb_page_canvas=Wênekoka rûpelê {{page}}
 
 # Find panel button title and messages
-find_label=Bibîne:
 find_previous.title=Peyva berê bibîne
 find_previous_label=Paşve
 find_next.title=Peyya pêş bibîne
diff --git a/l10n/lg/viewer.properties b/l10n/lg/viewer.properties
index e333c4fcd..5658d5448 100644
--- a/l10n/lg/viewer.properties
+++ b/l10n/lg/viewer.properties
@@ -58,7 +58,6 @@ bookmark_label=Endabika Eriwo
 document_outline_label=Ensalo ze Ekiwandiko
 thumbs.title=Laga Ekifanyi Mubufunze
 thumbs_label=Ekifanyi Mubufunze
-findbar_label=Zuula
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
diff --git a/l10n/lij/viewer.properties b/l10n/lij/viewer.properties
index bd1410a13..f01628dfd 100644
--- a/l10n/lij/viewer.properties
+++ b/l10n/lij/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Pagina {{page}}
 thumb_page_canvas=Miniatua da pagina {{page}}
 
 # Find panel button title and messages
-find_label=Treuva:
+find_input.title=Treuva
+find_input.placeholder=Treuva into documento…
 find_previous.title=Treuva a ripetiçion precedente do testo da çercâ
 find_previous_label=Precedente
 find_next.title=Treuva a ripetiçion dòppo do testo da çercâ
diff --git a/l10n/lt/viewer.properties b/l10n/lt/viewer.properties
index 6894bb698..9a9a08bfc 100644
--- a/l10n/lt/viewer.properties
+++ b/l10n/lt/viewer.properties
@@ -110,7 +110,6 @@ attachments_label=Priedai
 thumbs.title=Rodyti puslapių miniatiūras
 thumbs_label=Miniatiūros
 findbar.title=Ieškoti dokumente
-findbar_label=Ieškoti
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -121,7 +120,6 @@ thumb_page_title={{page}} puslapis
 thumb_page_canvas={{page}} puslapio miniatiūra
 
 # Find panel button title and messages
-find_label=Ieškoti:
 find_previous.title=Ieškoti ankstesnio frazės egzemplioriaus
 find_previous_label=Ankstesnis
 find_next.title=Ieškoti tolesnio frazės egzemplioriaus
diff --git a/l10n/lv/viewer.properties b/l10n/lv/viewer.properties
index 450f699db..9937df345 100644
--- a/l10n/lv/viewer.properties
+++ b/l10n/lv/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Lapa {{page}}
 thumb_page_canvas=Lapas {{page}} sīktēls
 
 # Find panel button title and messages
-find_label=Meklēt:
+find_input.title=Meklēt
+find_input.placeholder=Meklēt dokumentā…
 find_previous.title=Atrast iepriekšējo
 find_previous_label=Iepriekšējā
 find_next.title=Atrast nākamo
diff --git a/l10n/mai/viewer.properties b/l10n/mai/viewer.properties
index 022d56a2d..920ac7167 100644
--- a/l10n/mai/viewer.properties
+++ b/l10n/mai/viewer.properties
@@ -102,7 +102,6 @@ attachments_label=संलग्नक
 thumbs.title=लघु-छवि देखाउ
 thumbs_label=लघु छवि
 findbar.title=दस्तावेजमे ढूँढू
-findbar_label=ताकू
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -113,7 +112,6 @@ thumb_page_title=पृष्ठ {{page}}
 thumb_page_canvas=पृष्ठ {{page}} का लघु-चित्र
 
 # Find panel button title and messages
-find_label=ताकू:
 find_previous.title=खोजक पछिला उपस्थिति ताकू
 find_previous_label=पछिला
 find_next.title=खोजक अगिला उपस्थिति ताकू
diff --git a/l10n/mk/viewer.properties b/l10n/mk/viewer.properties
index 6200587a1..094ef7660 100644
--- a/l10n/mk/viewer.properties
+++ b/l10n/mk/viewer.properties
@@ -79,7 +79,6 @@ thumb_page_title=Страница {{page}}
 thumb_page_canvas=Икона од страница {{page}}
 
 # Find panel button title and messages
-find_label=Најди:
 find_previous.title=Најди ја предходната појава на фразата
 find_previous_label=Претходно
 find_next.title=Најди ја следната појава на фразата
diff --git a/l10n/ml/viewer.properties b/l10n/ml/viewer.properties
index d77d34c0e..f2c311527 100644
--- a/l10n/ml/viewer.properties
+++ b/l10n/ml/viewer.properties
@@ -102,7 +102,6 @@ attachments_label=അറ്റാച്മെന്റുകള്‍
 thumbs.title=തംബ്നെയിലുകള്‍ കാണിയ്ക്കുക
 thumbs_label=തംബ്നെയിലുകള്‍
 findbar.title=രേഖയില്‍ കണ്ടുപിടിയ്ക്കുക
-findbar_label=കണ്ടെത്തുക\u0020
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -113,7 +112,6 @@ thumb_page_title=താള്‍ {{page}}
 thumb_page_canvas={{page}} താളിനുള്ള തംബ്നെയില്‍
 
 # Find panel button title and messages
-find_label=കണ്ടെത്തുക
 find_previous.title=വാചകം ഇതിനു മുന്‍പ്‌ ആവര്‍ത്തിച്ചത്‌ കണ്ടെത്തുക\u0020
 find_previous_label=മുമ്പു്
 find_next.title=വാചകം വീണ്ടും ആവര്‍ത്തിക്കുന്നത്‌ കണ്ടെത്തുക\u0020
diff --git a/l10n/mn/viewer.properties b/l10n/mn/viewer.properties
index 138ce3c26..39edeb2b5 100644
--- a/l10n/mn/viewer.properties
+++ b/l10n/mn/viewer.properties
@@ -44,7 +44,6 @@ document_properties_title=Гарчиг:
 # Tooltips and alt text for side panel toolbar buttons
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
-findbar_label=Ол
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
diff --git a/l10n/mr/viewer.properties b/l10n/mr/viewer.properties
index f3e9e6717..887603f02 100644
--- a/l10n/mr/viewer.properties
+++ b/l10n/mr/viewer.properties
@@ -109,7 +109,6 @@ attachments_label=जोडपत्र
 thumbs.title=थंबनेल्स् दाखवा
 thumbs_label=थंबनेल्स्
 findbar.title=दस्तऐवजात शोधा
-findbar_label=शोधा
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -120,7 +119,6 @@ thumb_page_title=पृष्ठ {{page}}
 thumb_page_canvas=पृष्ठाचे थंबनेल {{page}}
 
 # Find panel button title and messages
-find_label=शोधा:
 find_previous.title=वाकप्रयोगची मागील घटना शोधा
 find_previous_label=मागील
 find_next.title=वाकप्रयोगची पुढील घटना शोधा
diff --git a/l10n/ms/viewer.properties b/l10n/ms/viewer.properties
index 533027f25..c7cb76b0f 100644
--- a/l10n/ms/viewer.properties
+++ b/l10n/ms/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Halaman {{page}}
 thumb_page_canvas=Halaman Imej kecil {{page}}
 
 # Find panel button title and messages
-find_label=Cari:
+find_input.title=Cari
+find_input.placeholder=Cari dalam dokumen…
 find_previous.title=Cari teks frasa berkenaan yang terdahulu
 find_previous_label=Sebelumnya
 find_next.title=Cari teks frasa berkenaan yang berikut
diff --git a/l10n/my/viewer.properties b/l10n/my/viewer.properties
index 271c6636b..6d5da642d 100644
--- a/l10n/my/viewer.properties
+++ b/l10n/my/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=စာမျက်နှာ {{page}}
 thumb_page_canvas=စာမျက်နှာရဲ့ ပုံရိပ်ငယ် {{page}}
 
 # Find panel button title and messages
-find_label=ရှာဖွေပါ -
+find_input.title=ရှာဖွေပါ
+find_input.placeholder=စာတမ်းထဲတွင် ရှာဖွေရန်…
 find_previous.title=စကားစုရဲ့ အရင် ​ဖြစ်ပွားမှုကို ရှာဖွေပါ
 find_previous_label=နောက်သို့
 find_next.title=စကားစုရဲ့ နောက်ထပ် ​ဖြစ်ပွားမှုကို ရှာဖွေပါ
diff --git a/l10n/nb-NO/viewer.properties b/l10n/nb-NO/viewer.properties
index 594a98b27..ff6063d97 100644
--- a/l10n/nb-NO/viewer.properties
+++ b/l10n/nb-NO/viewer.properties
@@ -121,7 +121,6 @@ thumb_page_title=Side {{page}}
 thumb_page_canvas=Miniatyrbilde av side {{page}}
 
 # Find panel button title and messages
-find_label=Finn:
 find_previous.title=Finn forrige forekomst av frasen
 find_previous_label=Forrige
 find_next.title=Finn neste forekomst av frasen
diff --git a/l10n/nn-NO/viewer.properties b/l10n/nn-NO/viewer.properties
index 83d0eec4c..01d80b8fc 100644
--- a/l10n/nn-NO/viewer.properties
+++ b/l10n/nn-NO/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Side {{page}}
 thumb_page_canvas=Miniatyrbilde av side {{page}}
 
 # Find panel button title and messages
-find_label=Finn:
+find_input.title=Søk
+find_input.placeholder=Søk i dokument…
 find_previous.title=Finn tidlegare førekomst av frasen
 find_previous_label=Føregåande
 find_next.title=Finn neste førekomst av frasen
diff --git a/l10n/nso/viewer.properties b/l10n/nso/viewer.properties
index c36b70aad..d95406c99 100644
--- a/l10n/nso/viewer.properties
+++ b/l10n/nso/viewer.properties
@@ -66,7 +66,6 @@ document_outline_label=Kakaretšo ya tokumente
 thumbs.title=Laetša dikhutšofatšo
 thumbs_label=Dikhutšofatšo
 findbar.title=Hwetša go tokumente
-findbar_label=Hwetša
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -77,7 +76,6 @@ thumb_page_title=Letlakala {{page}}
 thumb_page_canvas=Khutšofatšo ya letlakala {{page}}
 
 # Find panel button title and messages
-find_label=Hwetša:
 find_previous.title=Hwetša tiragalo e fetilego ya sekafoko
 find_previous_label=Fetilego
 find_next.title=Hwetša tiragalo e latelago ya sekafoko
diff --git a/l10n/oc/viewer.properties b/l10n/oc/viewer.properties
index 1b5572628..fbea26707 100644
--- a/l10n/oc/viewer.properties
+++ b/l10n/oc/viewer.properties
@@ -105,7 +105,6 @@ attachments_label=Pèças juntas
 thumbs.title=Afichar las vinhetas
 thumbs_label=Vinhetas
 findbar.title=Trobar dins lo document
-findbar_label=Recercar
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -116,7 +115,6 @@ thumb_page_title=Pagina {{page}}
 thumb_page_canvas=Vinheta de la pagina {{page}}
 
 # Find panel button title and messages
-find_label=Recercar
 find_previous.title=Tròba l'ocurréncia precedenta de la frasa
 find_previous_label=Precedent
 find_next.title=Tròba l'ocurréncia venenta de la frasa
diff --git a/l10n/or/viewer.properties b/l10n/or/viewer.properties
index 8d2e240ce..197f11bee 100644
--- a/l10n/or/viewer.properties
+++ b/l10n/or/viewer.properties
@@ -102,7 +102,6 @@ attachments_label=ସଲଗ୍ନକଗୁଡିକ
 thumbs.title=ସଂକ୍ଷିପ୍ତ ବିବରଣୀ ଦର୍ଶାନ୍ତୁ
 thumbs_label=ସଂକ୍ଷିପ୍ତ ବିବରଣୀ
 findbar.title=ଦଲିଲରେ ଖୋଜନ୍ତୁ
-findbar_label=ଖୋଜନ୍ତୁ
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -113,7 +112,6 @@ thumb_page_title=ପୃଷ୍ଠା {{page}}
 thumb_page_canvas=ପୃଷ୍ଠାର ସଂକ୍ଷିପ୍ତ ବିବରଣୀ {{page}}
 
 # Find panel button title and messages
-find_label=ଖୋଜନ୍ତୁ:
 find_previous.title=ଏହି ବାକ୍ୟାଂଶର ପୂର୍ବ ଉପସ୍ଥିତିକୁ ଖୋଜନ୍ତୁ
 find_previous_label=ପୂର୍ବବର୍ତ୍ତୀ
 find_next.title=ଏହି ବାକ୍ୟାଂଶର ପରବର୍ତ୍ତୀ ଉପସ୍ଥିତିକୁ ଖୋଜନ୍ତୁ
diff --git a/l10n/pa-IN/viewer.properties b/l10n/pa-IN/viewer.properties
index 65b2434ed..744ad0739 100644
--- a/l10n/pa-IN/viewer.properties
+++ b/l10n/pa-IN/viewer.properties
@@ -91,7 +91,6 @@ document_properties_version=PDF ਵਰਜਨ:
 document_properties_page_count=ਸਫ਼ੇ ਦੀ ਗਿਣਤੀ:
 document_properties_close=ਬੰਦ ਕਰੋ
 
-
 print_progress_message=Preparing document for printing…
 # LOCALIZATION NOTE (print_progress_percent): "{{progress}}" will be replaced by
 # a numerical per cent value.
@@ -122,7 +121,6 @@ thumb_page_title=ਸਫ਼ਾ {{page}}
 thumb_page_canvas={{page}} ਸਫ਼ੇ ਦਾ ਥੰਮਨੇਲ
 
 # Find panel button title and messages
-find_label=ਲੱਭੋ:
 find_previous.title=ਵਾਕ ਦੀ ਪਿਛਲੀ ਮੌਜੂਦਗੀ ਲੱਭੋ
 find_previous_label=ਪਿੱਛੇ
 find_next.title=ਵਾਕ ਦੀ ਅਗਲੀ ਮੌਜੂਦਗੀ ਲੱਭੋ
diff --git a/l10n/pl/viewer.properties b/l10n/pl/viewer.properties
index e2b6f7176..629bbcea2 100644
--- a/l10n/pl/viewer.properties
+++ b/l10n/pl/viewer.properties
@@ -85,7 +85,8 @@ findbar_label=Znajdź
 thumb_page_title=Strona {{page}}
 thumb_page_canvas=Miniaturka strony {{page}}
 
-find_label=Znajdź:
+find_input.title=Wyszukiwanie
+find_input.placeholder=Szukaj w dokumencie…
 find_previous.title=Znajdź poprzednie wystąpienie tekstu
 find_previous_label=Poprzednie
 find_next.title=Znajdź następne wystąpienie tekstu
diff --git a/l10n/pt-BR/viewer.properties b/l10n/pt-BR/viewer.properties
index 59ba6363a..9ff1d1398 100644
--- a/l10n/pt-BR/viewer.properties
+++ b/l10n/pt-BR/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Página {{page}}
 thumb_page_canvas=Miniatura da página {{page}}
 
 # Find panel button title and messages
-find_label=Localizar:
+find_input.title=Localizar
+find_input.placeholder=Localizar no documento…
 find_previous.title=Localizar a ocorrência anterior da frase
 find_previous_label=Anterior
 find_next.title=Localizar a próxima ocorrência da frase
diff --git a/l10n/pt-PT/viewer.properties b/l10n/pt-PT/viewer.properties
index f446995c4..89dfdedb3 100644
--- a/l10n/pt-PT/viewer.properties
+++ b/l10n/pt-PT/viewer.properties
@@ -32,8 +32,8 @@ zoom_out.title=Reduzir
 zoom_out_label=Reduzir
 zoom_in.title=Ampliar
 zoom_in_label=Ampliar
-zoom.title=Ampliação
-presentation_mode.title=Mudar para modo de apresentação
+zoom.title=Zoom
+presentation_mode.title=Trocar para o modo de apresentação
 presentation_mode_label=Modo de apresentação
 open_file.title=Abrir ficheiro
 open_file_label=Abrir
@@ -100,9 +100,9 @@ print_progress_close=Cancelar
 # Tooltips and alt text for side panel toolbar buttons
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
-toggle_sidebar.title=Comutar barra lateral
+toggle_sidebar.title=Alternar barra lateral
 toggle_sidebar_notification.title=Alternar barra lateral (documento contém contorno/anexos)
-toggle_sidebar_label=Comutar barra lateral
+toggle_sidebar_label=Alternar barra lateral
 document_outline.title=Mostrar limite do documento (duplo clique para expandir/colapsar todos os itens)
 document_outline_label=Estrutura do documento
 attachments.title=Mostrar anexos
@@ -121,14 +121,15 @@ thumb_page_title=Página {{page}}
 thumb_page_canvas=Miniatura da página {{page}}
 
 # Find panel button title and messages
-find_label=Localizar:
+find_input.title=Localizar
+find_input.placeholder=Localizar no documento…
 find_previous.title=Localizar ocorrência anterior da frase
 find_previous_label=Anterior
 find_next.title=Localizar ocorrência seguinte da frase
 find_next_label=Seguinte
 find_highlight=Destacar tudo
 find_match_case_label=Correspondência
-find_reached_top=Início de documento atingido, a continuar do fim
+find_reached_top=Topo do documento atingido, a continuar a partir do fundo
 find_reached_bottom=Fim do documento atingido, a continuar a partir do topo
 find_not_found=Frase não encontrada
 
@@ -154,7 +155,7 @@ rendering_error=Ocorreu um erro ao processar a página.
 # Predefined zoom values
 page_scale_width=Ajustar à largura
 page_scale_fit=Ajustar à página
-page_scale_auto=Tamanho automático
+page_scale_auto=Zoom automático
 page_scale_actual=Tamanho real
 # LOCALIZATION NOTE (page_scale_percent): "{{scale}}" will be replaced by a
 # numerical scale value.
diff --git a/l10n/rm/viewer.properties b/l10n/rm/viewer.properties
index e8b7b6ad7..3632fa2cb 100644
--- a/l10n/rm/viewer.properties
+++ b/l10n/rm/viewer.properties
@@ -121,7 +121,6 @@ thumb_page_title=Pagina {{page}}
 thumb_page_canvas=Miniatura da la pagina {{page}}
 
 # Find panel button title and messages
-find_label=Tschertgar:
 find_previous.title=Tschertgar la posiziun precedenta da l'expressiun
 find_previous_label=Enavos
 find_next.title=Tschertgar la proxima posiziun da l'expressiun
diff --git a/l10n/ro/viewer.properties b/l10n/ro/viewer.properties
index 77cc49d00..edd0b1a25 100644
--- a/l10n/ro/viewer.properties
+++ b/l10n/ro/viewer.properties
@@ -101,6 +101,7 @@ print_progress_close=Renunță
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
 toggle_sidebar.title=Comută bara laterală
+toggle_sidebar_notification.title=Comută bara laterală (documentul conține schițe/atașamente)
 toggle_sidebar_label=Comută bara laterală
 document_outline.title=Arată schița documentului (dublu-clic pentru a expanda/colapsa toate elementele
 document_outline_label=Schiță document
@@ -109,7 +110,6 @@ attachments_label=Atașamente
 thumbs.title=Arată miniaturi
 thumbs_label=Miniaturi
 findbar.title=Găsește în document
-findbar_label=Găsește
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -120,7 +120,6 @@ thumb_page_title=Pagina {{page}}
 thumb_page_canvas=Miniatura paginii {{page}}
 
 # Find panel button title and messages
-find_label=Găsește:
 find_previous.title=Găsește instanța anterioară în frază
 find_previous_label=Anterior
 find_next.title=Găsește instanța următoare în frază
diff --git a/l10n/ru/viewer.properties b/l10n/ru/viewer.properties
index 48af79208..ba1286781 100644
--- a/l10n/ru/viewer.properties
+++ b/l10n/ru/viewer.properties
@@ -1,116 +1,184 @@
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# Copyright 2012 Mozilla Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
-previous.title = Предыдущая страница
-previous_label = Предыдущая
-next.title = Следующая страница
-next_label = Следующая
-page.title = Страница
-of_pages = из {{pagesCount}}
-page_of_pages = ({{pageNumber}} из {{pagesCount}})
-zoom_out.title = Уменьшить
-zoom_out_label = Уменьшить
-zoom_in.title = Увеличить
-zoom_in_label = Увеличить
-zoom.title = Масштаб
-presentation_mode.title = Перейти в режим презентации
-presentation_mode_label = Режим презентации
-open_file.title = Открыть файл
-open_file_label = Открыть
-print.title = Печать
-print_label = Печать
-download.title = Загрузить
-download_label = Загрузить
-bookmark.title = Ссылка на текущий вид (скопировать или открыть в новом окне)
-bookmark_label = Текущий вид
-tools.title = Инструменты
-tools_label = Инструменты
-first_page.title = Перейти на первую страницу
-first_page.label = Перейти на первую страницу
-first_page_label = Перейти на первую страницу
-last_page.title = Перейти на последнюю страницу
-last_page.label = Перейти на последнюю страницу
-last_page_label = Перейти на последнюю страницу
-page_rotate_cw.title = Повернуть по часовой стрелке
-page_rotate_cw.label = Повернуть по часовой стрелке
-page_rotate_cw_label = Повернуть по часовой стрелке
-page_rotate_ccw.title = Повернуть против часовой стрелки
-page_rotate_ccw.label = Повернуть против часовой стрелки
-page_rotate_ccw_label = Повернуть против часовой стрелки
-hand_tool_enable.title = Включить Инструмент «Рука»
-hand_tool_enable_label = Включить Инструмент «Рука»
-hand_tool_disable.title = Отключить Инструмент «Рука»
-hand_tool_disable_label = Отключить Инструмент «Рука»
-document_properties.title = Свойства документа…
-document_properties_label = Свойства документа…
-document_properties_file_name = Имя файла:
-document_properties_file_size = Размер файла:
-document_properties_kb = {{size_kb}} КБ ({{size_b}} байт)
-document_properties_mb = {{size_mb}} МБ ({{size_b}} байт)
-document_properties_title = Заголовок:
-document_properties_author = Автор:
-document_properties_subject = Тема:
-document_properties_keywords = Ключевые слова:
-document_properties_creation_date = Дата создания:
-document_properties_modification_date = Дата изменения:
-document_properties_date_string = {{date}}, {{time}}
-document_properties_creator = Приложение:
-document_properties_producer = Производитель PDF:
-document_properties_version = Версия PDF:
-document_properties_page_count = Число страниц:
-document_properties_close = Закрыть
-print_progress_message = Подготовка документа к печати…
-print_progress_percent = {{progress}}%
-print_progress_close = Отмена
-toggle_sidebar.title = Показать/скрыть боковую панель
-toggle_sidebar_notification.title = Показать/скрыть боковую панель (документ имеет содержание/вложения)
-toggle_sidebar_label = Показать/скрыть боковую панель
-document_outline.title = Показать содержание документа (двойной щелчок, чтобы развернуть/свернуть все элементы)
-document_outline_label = Содержание документа
-attachments.title = Показать вложения
-attachments_label = Вложения
-thumbs.title = Показать миниатюры
-thumbs_label = Миниатюры
-findbar.title = Найти в документе
-findbar_label = Найти
-thumb_page_title = Страница {{page}}
-thumb_page_canvas = Миниатюра страницы {{page}}
-find_label = Найти:
-find_previous.title = Найти предыдущее вхождение фразы в текст
-find_previous_label = Назад
-find_next.title = Найти следующее вхождение фразы в текст
-find_next_label = Далее
-find_highlight = Подсветить все
-find_match_case_label = С учётом регистра
-find_reached_top = Достигнут верх документа, продолжено снизу
-find_reached_bottom = Достигнут конец документа, продолжено сверху
-find_not_found = Фраза не найдена
-error_more_info = Детали
-error_less_info = Скрыть детали
-error_close = Закрыть
-error_version_info = PDF.js v{{version}} (сборка: {{build}})
-error_message = Сообщение: {{message}}
-error_stack = Стeк: {{stack}}
-error_file = Файл: {{file}}
-error_line = Строка: {{line}}
-rendering_error = При создании страницы произошла ошибка.
-page_scale_width = По ширине страницы
-page_scale_fit = По размеру страницы
-page_scale_auto = Автоматически
-page_scale_actual = Реальный размер
-page_scale_percent = {{scale}}%
-loading_error_indicator = Ошибка
-loading_error = При загрузке PDF произошла ошибка.
-invalid_file_error = Некорректный или повреждённый PDF-файл.
-missing_file_error = PDF-файл отсутствует.
-unexpected_response_error = Неожиданный ответ сервера.
-text_annotation_type.alt = [Аннотация {{type}}]
-password_label = Введите пароль, чтобы открыть этот PDF-файл.
-password_invalid = Неверный пароль. Пожалуйста, попробуйте снова.
-password_ok = OK
-password_cancel = Отмена
-printing_not_supported = Предупреждение: В этом браузере не полностью поддерживается печать.
-printing_not_ready = Предупреждение: PDF не полностью загружен для печати.
-web_fonts_disabled = Веб-шрифты отключены: невозможно использовать встроенные PDF-шрифты.
-document_colors_not_allowed = PDF-документам не разрешено использовать свои цвета: в браузере отключён параметр «Разрешить веб-сайтам использовать свои цвета».
+# Main toolbar buttons (tooltips and alt text for images)
+previous.title=Предыдущая страница
+previous_label=Предыдущая
+next.title=Следующая страница
+next_label=Следующая
+
+# LOCALIZATION NOTE (page.title): The tooltip for the pageNumber input.
+page.title=Страница
+# LOCALIZATION NOTE (of_pages): "{{pagesCount}}" will be replaced by a number
+# representing the total number of pages in the document.
+of_pages=из {{pagesCount}}
+# LOCALIZATION NOTE (page_of_pages): "{{pageNumber}}" and "{{pagesCount}}"
+# will be replaced by a number representing the currently visible page,
+# respectively a number representing the total number of pages in the document.
+page_of_pages=({{pageNumber}} из {{pagesCount}})
+
+zoom_out.title=Уменьшить
+zoom_out_label=Уменьшить
+zoom_in.title=Увеличить
+zoom_in_label=Увеличить
+zoom.title=Масштаб
+presentation_mode.title=Перейти в режим презентации
+presentation_mode_label=Режим презентации
+open_file.title=Открыть файл
+open_file_label=Открыть
+print.title=Печать
+print_label=Печать
+download.title=Загрузить
+download_label=Загрузить
+bookmark.title=Ссылка на текущий вид (скопировать или открыть в новом окне)
+bookmark_label=Текущий вид
+
+# Secondary toolbar and context menu
+tools.title=Инструменты
+tools_label=Инструменты
+first_page.title=Перейти на первую страницу
+first_page.label=Перейти на первую страницу
+first_page_label=Перейти на первую страницу
+last_page.title=Перейти на последнюю страницу
+last_page.label=Перейти на последнюю страницу
+last_page_label=Перейти на последнюю страницу
+page_rotate_cw.title=Повернуть по часовой стрелке
+page_rotate_cw.label=Повернуть по часовой стрелке
+page_rotate_cw_label=Повернуть по часовой стрелке
+page_rotate_ccw.title=Повернуть против часовой стрелки
+page_rotate_ccw.label=Повернуть против часовой стрелки
+page_rotate_ccw_label=Повернуть против часовой стрелки
+
+hand_tool_enable.title=Включить Инструмент «Рука»
+hand_tool_enable_label=Включить Инструмент «Рука»
+hand_tool_disable.title=Отключить Инструмент «Рука»
+hand_tool_disable_label=Отключить Инструмент «Рука»
+
+# Document properties dialog box
+document_properties.title=Свойства документа…
+document_properties_label=Свойства документа…
+document_properties_file_name=Имя файла:
+document_properties_file_size=Размер файла:
+# LOCALIZATION NOTE (document_properties_kb): "{{size_kb}}" and "{{size_b}}"
+# will be replaced by the PDF file size in kilobytes, respectively in bytes.
+document_properties_kb={{size_kb}} КБ ({{size_b}} байт)
+# LOCALIZATION NOTE (document_properties_mb): "{{size_mb}}" and "{{size_b}}"
+# will be replaced by the PDF file size in megabytes, respectively in bytes.
+document_properties_mb={{size_mb}} МБ ({{size_b}} байт)
+document_properties_title=Заголовок:
+document_properties_author=Автор:
+document_properties_subject=Тема:
+document_properties_keywords=Ключевые слова:
+document_properties_creation_date=Дата создания:
+document_properties_modification_date=Дата изменения:
+# LOCALIZATION NOTE (document_properties_date_string): "{{date}}" and "{{time}}"
+# will be replaced by the creation/modification date, and time, of the PDF file.
+document_properties_date_string={{date}}, {{time}}
+document_properties_creator=Приложение:
+document_properties_producer=Производитель PDF:
+document_properties_version=Версия PDF:
+document_properties_page_count=Число страниц:
+document_properties_close=Закрыть
+
+print_progress_message=Подготовка документа к печати…
+# LOCALIZATION NOTE (print_progress_percent): "{{progress}}" will be replaced by
+# a numerical per cent value.
+print_progress_percent={{progress}}%
+print_progress_close=Отмена
+
+# Tooltips and alt text for side panel toolbar buttons
+# (the _label strings are alt text for the buttons, the .title strings are
+# tooltips)
+toggle_sidebar.title=Показать/скрыть боковую панель
+toggle_sidebar_notification.title=Показать/скрыть боковую панель (документ имеет содержание/вложения)
+toggle_sidebar_label=Показать/скрыть боковую панель
+document_outline.title=Показать содержание документа (двойной щелчок, чтобы развернуть/свернуть все элементы)
+document_outline_label=Содержание документа
+attachments.title=Показать вложения
+attachments_label=Вложения
+thumbs.title=Показать миниатюры
+thumbs_label=Миниатюры
+findbar.title=Найти в документе
+findbar_label=Найти
+
+# Thumbnails panel item (tooltip and alt text for images)
+# LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
+# number.
+thumb_page_title=Страница {{page}}
+# LOCALIZATION NOTE (thumb_page_canvas): "{{page}}" will be replaced by the page
+# number.
+thumb_page_canvas=Миниатюра страницы {{page}}
+
+# Find panel button title and messages
+find_input.title=Найти
+find_input.placeholder=Найти в документе…
+find_previous.title=Найти предыдущее вхождение фразы в текст
+find_previous_label=Назад
+find_next.title=Найти следующее вхождение фразы в текст
+find_next_label=Далее
+find_highlight=Подсветить все
+find_match_case_label=С учётом регистра
+find_reached_top=Достигнут верх документа, продолжено снизу
+find_reached_bottom=Достигнут конец документа, продолжено сверху
+find_not_found=Фраза не найдена
+
+# Error panel labels
+error_more_info=Детали
+error_less_info=Скрыть детали
+error_close=Закрыть
+# LOCALIZATION NOTE (error_version_info): "{{version}}" and "{{build}}" will be
+# replaced by the PDF.JS version and build ID.
+error_version_info=PDF.js v{{version}} (сборка: {{build}})
+# LOCALIZATION NOTE (error_message): "{{message}}" will be replaced by an
+# english string describing the error.
+error_message=Сообщение: {{message}}
+# LOCALIZATION NOTE (error_stack): "{{stack}}" will be replaced with a stack
+# trace.
+error_stack=Стeк: {{stack}}
+# LOCALIZATION NOTE (error_file): "{{file}}" will be replaced with a filename
+error_file=Файл: {{file}}
+# LOCALIZATION NOTE (error_line): "{{line}}" will be replaced with a line number
+error_line=Строка: {{line}}
+rendering_error=При создании страницы произошла ошибка.
+
+# Predefined zoom values
+page_scale_width=По ширине страницы
+page_scale_fit=По размеру страницы
+page_scale_auto=Автоматически
+page_scale_actual=Реальный размер
+# LOCALIZATION NOTE (page_scale_percent): "{{scale}}" will be replaced by a
+# numerical scale value.
+page_scale_percent={{scale}}%
+
+# Loading indicator messages
+loading_error_indicator=Ошибка
+loading_error=При загрузке PDF произошла ошибка.
+invalid_file_error=Некорректный или повреждённый PDF-файл.
+missing_file_error=PDF-файл отсутствует.
+unexpected_response_error=Неожиданный ответ сервера.
+
+# LOCALIZATION NOTE (text_annotation_type.alt): This is used as a tooltip.
+# "{{type}}" will be replaced with an annotation type from a list defined in
+# the PDF spec (32000-1:2008 Table 169 – Annotation types).
+# Some common types are e.g.: "Check", "Text", "Comment", "Note"
+text_annotation_type.alt=[Аннотация {{type}}]
+password_label=Введите пароль, чтобы открыть этот PDF-файл.
+password_invalid=Неверный пароль. Пожалуйста, попробуйте снова.
+password_ok=OK
+password_cancel=Отмена
+
+printing_not_supported=Предупреждение: В этом браузере не полностью поддерживается печать.
+printing_not_ready=Предупреждение: PDF не полностью загружен для печати.
+web_fonts_disabled=Веб-шрифты отключены: невозможно использовать встроенные PDF-шрифты.
+document_colors_not_allowed=PDF-документам не разрешено использовать свои цвета: в браузере отключён параметр «Разрешить веб-сайтам использовать свои цвета».
diff --git a/l10n/rw/viewer.properties b/l10n/rw/viewer.properties
index 04889324e..68a893d30 100644
--- a/l10n/rw/viewer.properties
+++ b/l10n/rw/viewer.properties
@@ -43,7 +43,6 @@ document_properties_title=Umutwe:
 # Tooltips and alt text for side panel toolbar buttons
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
-findbar_label=Gushakisha
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -52,7 +51,6 @@ findbar_label=Gushakisha
 # number.
 
 # Find panel button title and messages
-find_label="Gushaka:"
 find_previous.title=Gushaka aho uyu murongo ugaruka mbere y'aha
 find_next.title=Gushaka aho uyu murongo wongera kugaruka
 find_not_found=Umurongo ntubonetse
diff --git a/l10n/sah/viewer.properties b/l10n/sah/viewer.properties
index 0a9d2a83d..ff8371f3b 100644
--- a/l10n/sah/viewer.properties
+++ b/l10n/sah/viewer.properties
@@ -101,7 +101,6 @@ attachments_label=Кыбытык
 thumbs.title=Ойуучааннары көрдөр
 thumbs_label=Ойуучааннар
 findbar.title=Дөкүмүөнтэн бул
-findbar_label=Бул
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -112,7 +111,6 @@ thumb_page_title=Сирэй {{page}}
 thumb_page_canvas=Сирэй ойуучаана {{page}}
 
 # Find panel button title and messages
-find_label=Бул:
 find_previous.title=Этии тиэкискэ бу иннинээҕи киириитин бул
 find_previous_label=Иннинээҕи
 find_next.title=Этии тиэкискэ бу кэннинээҕи киириитин бул
diff --git a/l10n/si/viewer.properties b/l10n/si/viewer.properties
index f96b7dea8..19cd922c9 100644
--- a/l10n/si/viewer.properties
+++ b/l10n/si/viewer.properties
@@ -115,7 +115,6 @@ thumb_page_title=පිටුව {{page}}
 thumb_page_canvas=පිටුවෙ සිඟිත රූව {{page}}
 
 # Find panel button title and messages
-find_label=සොයන්න:
 find_previous.title=මේ වාක්‍ය ඛණ්ඩය මීට පෙර යෙදුණු ස්ථානය සොයන්න
 find_previous_label=පෙර:
 find_next.title=මේ වාක්‍ය ඛණ්ඩය මීළඟට යෙදෙන ස්ථානය සොයන්න
diff --git a/l10n/sk/viewer.properties b/l10n/sk/viewer.properties
index 4521e59eb..33e0dae08 100644
--- a/l10n/sk/viewer.properties
+++ b/l10n/sk/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Strana {{page}}
 thumb_page_canvas=Miniatúra strany {{page}}
 
 # Find panel button title and messages
-find_label=Hľadať:
+find_input.title=Hľadať
+find_input.placeholder=Hľadať v dokumente…
 find_previous.title=Vyhľadať predchádzajúci výskyt reťazca
 find_previous_label=Predchádzajúce
 find_next.title=Vyhľadať ďalší výskyt reťazca
diff --git a/l10n/sl/viewer.properties b/l10n/sl/viewer.properties
index 593f2bebb..747a94226 100644
--- a/l10n/sl/viewer.properties
+++ b/l10n/sl/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Stran {{page}}
 thumb_page_canvas=Sličica strani {{page}}
 
 # Find panel button title and messages
-find_label=Najdi:
+find_input.title=Najdi
+find_input.placeholder=Najdi v dokumentu …
 find_previous.title=Najdi prejšnjo ponovitev iskanega
 find_previous_label=Najdi nazaj
 find_next.title=Najdi naslednjo ponovitev iskanega
diff --git a/l10n/son/viewer.properties b/l10n/son/viewer.properties
index da4d47fb8..f9417ae6a 100644
--- a/l10n/son/viewer.properties
+++ b/l10n/son/viewer.properties
@@ -101,6 +101,7 @@ print_progress_close=Naŋ
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
 toggle_sidebar.title=Kanjari ceraw zuu
+toggle_sidebar_notification.title=Kanjari ceraw-zuu (takaddaa goo nda filla-boŋ/hangandiyaŋ)
 toggle_sidebar_label=Kanjari ceraw zuu
 document_outline.title=Takaddaa korfur alhaaloo cebe (naagu cee hinka ka haya-izey kul hayandi/kankamandi)
 document_outline_label=Takadda filla-boŋ
@@ -120,7 +121,8 @@ thumb_page_title={{page}} moo
 thumb_page_canvas=Kabeboy bii {{page}} moo še
 
 # Find panel button title and messages
-find_label=Ceeci:
+find_input.title=Ceeci
+find_input.placeholder=Ceeci takaddaa ra…
 find_previous.title=Kalimaɲaŋoo bangayri bisantaa ceeci
 find_previous_label=Bisante
 find_next.title=Kalimaɲaŋoo hiino bangayroo ceeci
diff --git a/l10n/sq/viewer.properties b/l10n/sq/viewer.properties
index 2f5f87e45..d4b242995 100644
--- a/l10n/sq/viewer.properties
+++ b/l10n/sq/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Faqja {{page}}
 thumb_page_canvas=Miniaturë e Faqes {{page}}
 
 # Find panel button title and messages
-find_label=Gjej:
+find_input.title=Gjeje
+find_input.placeholder=Gjeni në dokument…
 find_previous.title=Gjeni hasjen e mëparshme të togfjalëshit
 find_previous_label=E mëparshmja
 find_next.title=Gjeni hasjen pasuese të togfjalëshit
diff --git a/l10n/sr/viewer.properties b/l10n/sr/viewer.properties
index 33f1687ec..8530163e1 100644
--- a/l10n/sr/viewer.properties
+++ b/l10n/sr/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Страница {{page}}
 thumb_page_canvas=Сличица од странице {{page}}
 
 # Find panel button title and messages
-find_label=Пронађи:
+find_input.title=Пронађи
+find_input.placeholder=Пронађи у документу…
 find_previous.title=Пронађи претходну појаву фразе
 find_previous_label=Претходна
 find_next.title=Пронађи следећу појаву фразе
diff --git a/l10n/sv-SE/viewer.properties b/l10n/sv-SE/viewer.properties
index 4c59886dc..4df0af9e3 100644
--- a/l10n/sv-SE/viewer.properties
+++ b/l10n/sv-SE/viewer.properties
@@ -122,7 +122,7 @@ thumb_page_canvas=Miniatyr av sida {{page}}
 
 # Find panel button title and messages
 find_input.title=Sök
-find_input.placeholder=Sök i dokumentet…
+find_input.placeholder=Sök i dokument…
 find_previous.title=Hitta föregående förekomst av frasen
 find_previous_label=Föregående
 find_next.title=Hitta nästa förekomst av frasen
diff --git a/l10n/sw/viewer.properties b/l10n/sw/viewer.properties
index 4df8285f4..9ec4e2160 100644
--- a/l10n/sw/viewer.properties
+++ b/l10n/sw/viewer.properties
@@ -65,7 +65,6 @@ document_outline_label=Ufupisho wa Waraka
 thumbs.title=Onyesha Kijipicha
 thumbs_label=Vijipicha
 findbar.title=Pata katika Waraka
-findbar_label=Tafuta
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -76,7 +75,6 @@ thumb_page_title=Ukurasa {{ukurasa}}
 thumb_page_canvas=Kijipicha cha ukurasa {{ukurasa}}
 
 # Find panel button title and messages
-find_label=Tafuta:
 find_previous.title=Tafuta tukio kabla ya msemo huu
 find_previous_label=Iliyotangulia
 find_next.title=Tafuta tukio linalofuata la msemo
diff --git a/l10n/ta/viewer.properties b/l10n/ta/viewer.properties
index fe49ab7e9..13834527a 100644
--- a/l10n/ta/viewer.properties
+++ b/l10n/ta/viewer.properties
@@ -107,7 +107,6 @@ attachments_label=இணைப்புகள்
 thumbs.title=சிறுபடங்களைக் காண்பி
 thumbs_label=சிறுபடங்கள்
 findbar.title=ஆவணத்தில் கண்டறி
-findbar_label=கண்டுபிடி
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -118,7 +117,6 @@ thumb_page_title=பக்கம் {{page}}
 thumb_page_canvas=பக்கத்தின் சிறுபடம் {{page}}
 
 # Find panel button title and messages
-find_label=கண்டறி:
 find_previous.title=இந்த சொற்றொடரின் முந்தைய நிகழ்வை தேடு
 find_previous_label=முந்தையது
 find_next.title=இந்த சொற்றொடரின் அடுத்த நிகழ்வை தேடு
diff --git a/l10n/te/viewer.properties b/l10n/te/viewer.properties
index 055ea1e21..e144db046 100644
--- a/l10n/te/viewer.properties
+++ b/l10n/te/viewer.properties
@@ -120,7 +120,6 @@ thumb_page_title=పేజీ {{page}}
 thumb_page_canvas=పేజీ {{page}} యొక్క థంబ్‌నైల్
 
 # Find panel button title and messages
-find_label=కనుగొను:
 find_previous.title=పదం యొక్క ముందు సంభవాన్ని కనుగొను
 find_previous_label=మునుపటి
 find_next.title=పదం యొక్క తర్వాతి సంభవాన్ని కనుగొను
diff --git a/l10n/th/viewer.properties b/l10n/th/viewer.properties
index bb824fde5..96183637c 100644
--- a/l10n/th/viewer.properties
+++ b/l10n/th/viewer.properties
@@ -101,6 +101,7 @@ print_progress_close=ยกเลิก
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
 toggle_sidebar.title=เปิด/ปิดแถบข้าง
+toggle_sidebar_notification.title=เปิด/ปิดแถบข้าง (เอกสารมีเค้าร่าง/ไฟล์แนบ)
 toggle_sidebar_label=เปิด/ปิดแถบข้าง
 document_outline.title=แสดงเค้าร่างเอกสาร (คลิกสองครั้งเพื่อขยาย/ยุบรายการทั้งหมด)
 document_outline_label=เค้าร่างเอกสาร
@@ -120,7 +121,8 @@ thumb_page_title=หน้า {{page}}
 thumb_page_canvas=ภาพขนาดย่อของหน้า {{page}}
 
 # Find panel button title and messages
-find_label=ค้นหา:
+find_input.title=ค้นหา
+find_input.placeholder=ค้นหาในเอกสาร…
 find_previous.title=หาตำแหน่งก่อนหน้าของวลี
 find_previous_label=ก่อนหน้า
 find_next.title=หาตำแหน่งถัดไปของวลี
diff --git a/l10n/tl/viewer.properties b/l10n/tl/viewer.properties
index 638568710..de4d1bf6f 100644
--- a/l10n/tl/viewer.properties
+++ b/l10n/tl/viewer.properties
@@ -44,6 +44,7 @@ document_properties_title=Pamagat:
 
 # LOCALIZATION NOTE (print_progress_percent): "{{progress}}" will be replaced by
 # a numerical per cent value.
+print_progress_close=Kanselahin
 
 # Tooltips and alt text for side panel toolbar buttons
 # (the _label strings are alt text for the buttons, the .title strings are
@@ -92,4 +93,5 @@ loading_error=May maling nangyari habang kinakarga ang PDF.
 # the PDF spec (32000-1:2008 Table 169 – Annotation types).
 # Some common types are e.g.: "Check", "Text", "Comment", "Note"
 password_ok=OK
+password_cancel=Kanselahin
 
diff --git a/l10n/tn/viewer.properties b/l10n/tn/viewer.properties
index 6ce5eb463..ca7b86082 100644
--- a/l10n/tn/viewer.properties
+++ b/l10n/tn/viewer.properties
@@ -46,7 +46,6 @@ document_properties_title=Leina:
 # Tooltips and alt text for side panel toolbar buttons
 # (the _label strings are alt text for the buttons, the .title strings are
 # tooltips)
-findbar_label=Batla
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
diff --git a/l10n/tr/viewer.properties b/l10n/tr/viewer.properties
index c149c6b6c..459ba1459 100644
--- a/l10n/tr/viewer.properties
+++ b/l10n/tr/viewer.properties
@@ -28,8 +28,8 @@ of_pages=/ {{pagesCount}}
 # respectively a number representing the total number of pages in the document.
 page_of_pages=({{pageNumber}} / {{pagesCount}})
 
-zoom_out.title=Uzaklaștır
-zoom_out_label=Uzaklaștır
+zoom_out.title=Uzaklaştır
+zoom_out_label=Uzaklaştır
 zoom_in.title=Yaklaştır
 zoom_in_label=Yaklaştır
 zoom.title=Yakınlaştırma
@@ -121,13 +121,14 @@ thumb_page_title=Sayfa {{page}}
 thumb_page_canvas={{page}}. sayfanın küçük hâli
 
 # Find panel button title and messages
-find_label=Bul:
+find_input.title=Bul
+find_input.placeholder=Belgede bul…
 find_previous.title=Önceki eşleşmeyi bul
 find_previous_label=Önceki
 find_next.title=Sonraki eşleşmeyi bul
 find_next_label=Sonraki
 find_highlight=Tümünü vurgula
-find_match_case_label=Büyük-küçük harf eşleştir
+find_match_case_label=Büyük-küçük harfe duyarlı
 find_reached_top=Belgenin başına ulaşıldı, sonundan devam edildi
 find_reached_bottom=Belgenin sonuna ulaşıldı, başından devam edildi
 find_not_found=Eşleşme bulunamadı
diff --git a/l10n/uk/viewer.properties b/l10n/uk/viewer.properties
index 626f11ea1..08de774f5 100644
--- a/l10n/uk/viewer.properties
+++ b/l10n/uk/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=Сторінка {{page}}
 thumb_page_canvas=Ескіз сторінки {{page}}
 
 # Find panel button title and messages
-find_label=Знайти:
+find_input.title=Знайти
+find_input.placeholder=Знайти в документі…
 find_previous.title=Знайти попереднє входження фрази
 find_previous_label=Попереднє
 find_next.title=Знайти наступне входження фрази
diff --git a/l10n/ur/viewer.properties b/l10n/ur/viewer.properties
index e9c380267..2625c03ef 100644
--- a/l10n/ur/viewer.properties
+++ b/l10n/ur/viewer.properties
@@ -109,7 +109,6 @@ attachments_label=منسلکات
 thumbs.title=تھمبنیل دکھائیں
 thumbs_label=مجمل
 findbar.title=دستاویز میں ڈھونڈیں
-findbar_label=ڈھونڈیں
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -120,7 +119,6 @@ thumb_page_title=صفحہ {{page}}
 thumb_page_canvas=صفحے کا مجمل {{page}}
 
 # Find panel button title and messages
-find_label=ڈھونڈیں:
 find_previous.title=فقرے کا پچھلا وقوع ڈھونڈیں
 find_previous_label=پچھلا
 find_next.title=فقرے کا اگلہ وقوع ڈھونڈیں
diff --git a/l10n/vi/viewer.properties b/l10n/vi/viewer.properties
index c315589e3..97bb11a71 100644
--- a/l10n/vi/viewer.properties
+++ b/l10n/vi/viewer.properties
@@ -25,6 +25,7 @@ of_pages=trên {{pagesCount}}
 # LOCALIZATION NOTE (page_of_pages): "{{pageNumber}}" and "{{pagesCount}}"
 # will be replaced by a number representing the currently visible page,
 # respectively a number representing the total number of pages in the document.
+page_of_pages=({{pageNumber}} trên {{pagesCount}})
 
 zoom_out.title=Thu nhỏ
 zoom_out_label=Thu nhỏ
@@ -89,8 +90,10 @@ document_properties_version=Phiên bản PDF:
 document_properties_page_count=Tổng số trang:
 document_properties_close=Ðóng
 
+print_progress_message=Chuẩn bị trang để in…
 # LOCALIZATION NOTE (print_progress_percent): "{{progress}}" will be replaced by
 # a numerical per cent value.
+print_progress_percent={{progress}}%
 
 # Tooltips and alt text for side panel toolbar buttons
 # (the _label strings are alt text for the buttons, the .title strings are
@@ -103,7 +106,6 @@ attachments_label=Nội dung đính kèm
 thumbs.title=Hiển thị ảnh thu nhỏ
 thumbs_label=Ảnh thu nhỏ
 findbar.title=Tìm trong tài liệu
-findbar_label=Tìm
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -114,7 +116,6 @@ thumb_page_title=Trang {{page}}
 thumb_page_canvas=Ảnh thu nhỏ của trang {{page}}
 
 # Find panel button title and messages
-find_label=Tìm:
 find_previous.title=Tìm cụm từ ở phần trước
 find_previous_label=Trước
 find_next.title=Tìm cụm từ ở phần sau
diff --git a/l10n/wo/viewer.properties b/l10n/wo/viewer.properties
index ee79d8260..8c999ad0e 100644
--- a/l10n/wo/viewer.properties
+++ b/l10n/wo/viewer.properties
@@ -73,7 +73,6 @@ thumb_page_title=Xët {{xët}}
 thumb_page_canvas=Wiñet bu xët{{xët}}
 
 # Find panel button title and messages
-find_label=Wut:
 find_previous.title=Seet beneen kaddu bu ni mel te jiitu
 find_previous_label=Bi jiitu
 find_next.title=Seet beneen kaddu bu ni mel
diff --git a/l10n/xh/viewer.properties b/l10n/xh/viewer.properties
index 0694e2f38..c897c9d6f 100644
--- a/l10n/xh/viewer.properties
+++ b/l10n/xh/viewer.properties
@@ -110,7 +110,6 @@ attachments_label=Iziqhoboshelo
 thumbs.title=Bonisa ukrobiso kumfanekiso
 thumbs_label=Ukrobiso kumfanekiso
 findbar.title=Fumana kuXwebhu
-findbar_label=Fumana
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -121,7 +120,6 @@ thumb_page_title=Iphepha {{page}}
 thumb_page_canvas=Ukrobiso kumfanekiso wephepha {{page}}
 
 # Find panel button title and messages
-find_label=Fumanisa:
 find_previous.title=Fumanisa isenzeko sangaphambili sebinzana lamagama
 find_previous_label=Okwangaphambili
 find_next.title=Fumanisa isenzeko esilandelayo sebinzana lamagama
diff --git a/l10n/zh-CN/viewer.properties b/l10n/zh-CN/viewer.properties
index 664efbcbd..cdd495671 100644
--- a/l10n/zh-CN/viewer.properties
+++ b/l10n/zh-CN/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=页码 {{page}}
 thumb_page_canvas=页面 {{page}} 的缩略图
 
 # Find panel button title and messages
-find_label=查找:
+find_input.title=查找
+find_input.placeholder=在文档中查找…
 find_previous.title=查找词语上一次出现的位置
 find_previous_label=上一页
 find_next.title=查找词语后一次出现的位置
diff --git a/l10n/zh-TW/viewer.properties b/l10n/zh-TW/viewer.properties
index 72b094d17..7103fb749 100644
--- a/l10n/zh-TW/viewer.properties
+++ b/l10n/zh-TW/viewer.properties
@@ -121,7 +121,8 @@ thumb_page_title=頁 {{page}}
 thumb_page_canvas=頁 {{page}} 的縮圖
 
 # Find panel button title and messages
-find_label=尋找:
+find_input.title=搜尋
+find_input.placeholder=在文件中搜尋…
 find_previous.title=尋找文字前次出現的位置
 find_previous_label=上一個
 find_next.title=尋找文字下次出現的位置
diff --git a/l10n/zu/viewer.properties b/l10n/zu/viewer.properties
index 2e49fa8e7..8fc77f28f 100644
--- a/l10n/zu/viewer.properties
+++ b/l10n/zu/viewer.properties
@@ -66,7 +66,6 @@ document_outline_label=Umugqa waseceleni wedokhumenti
 thumbs.title=Bonisa izithombe ezincane
 thumbs_label=Izithonjana
 findbar.title=Thola kwidokhumenti
-findbar_label=Thola
 
 # Thumbnails panel item (tooltip and alt text for images)
 # LOCALIZATION NOTE (thumb_page_title): "{{page}}" will be replaced by the page
@@ -77,7 +76,6 @@ thumb_page_title=Ikhasi {{page}}
 thumb_page_canvas=Isithonjana sekhasi {{page}}
 
 # Find panel button title and messages
-find_label=Thola
 find_previous.title=Thola indawo eyandulelayo okuvela kuyo lomshwana
 find_previous_label=Okudlulile
 find_next.title=Thola enye indawo okuvela kuyo lomshwana
diff --git a/external/importL10n/locales.js b/external/importL10n/locales.js
index f4bb1ac56..2b0bcf2fa 100644
--- a/external/importL10n/locales.js
+++ b/external/importL10n/locales.js
@@ -19,7 +19,7 @@ var fs = require('fs');
 var https = require('https');
 var path = require('path');
 
 // Defines all languages that have a translation at mozilla-beta.
 // This is used in make.js for the importl10n command.
 var langCodes = [
   'ach', 'af', 'ak', 'an', 'ar', 'as', 'ast', 'az', 'be', 'bg',
@@ -44,10 +44,9 @@ function downloadLanguageFiles(root, langCode, callback) {
   console.log('Downloading ' + langCode + '...');
 
   // Constants for constructing the URLs. Translations are taken from the
-  // Beta channel as those are the most recent ones. The Nightly channel
-  // does not provide all translations.
-  var MOZ_BETA_ROOT = 'https://hg.mozilla.org/releases/l10n/mozilla-beta/';
-  var MOZ_BETA_PDFJS_DIR = '/raw-file/tip/browser/pdfviewer/';
+  // Nightly channel as those are the most recent ones.
+  var MOZ_CENTRAL_ROOT = 'https://hg.mozilla.org/l10n-central/';
+  var MOZ_CENTRAL_PDFJS_DIR = '/raw-file/tip/browser/pdfviewer/';
 
   // Defines which files to download for each language.
   var files = ['chrome.properties', 'viewer.properties'];
@@ -61,7 +60,7 @@ function downloadLanguageFiles(root, langCode, callback) {
   // Download the necessary files for this language.
   files.forEach(function(fileName) {
     var outputPath = path.join(outputDir, fileName);
-    var url = MOZ_BETA_ROOT + langCode + MOZ_BETA_PDFJS_DIR + fileName;
+    var url = MOZ_CENTRAL_ROOT + langCode + MOZ_CENTRAL_PDFJS_DIR + fileName;
 
     https.get(url, function(response) {
       var content = '';
@@ -19,7 +19,7 @@ var fs = require('fs');
 var path = require('path');
 
-// Defines all languages that have a translation at mozilla-beta.
+// Defines all languages that have a translation at mozilla-central.
 // This is used in make.js for the importl10n command.
 var langCodes = [
